==> genai_perf-0.0.9.dev0-py3-none-any.whl: genai_perf/export_data/console_exporter.py <==
# Copyright 2024, NVIDIA CORPORATION & AFFILIATES. All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#  * Neither the name of NVIDIA CORPORATION nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS ``AS IS'' AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
# OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from genai_perf.export_data import telemetry_data_exporter_util as telem_utils
from genai_perf.export_data.exporter_config import ExporterConfig
from rich.console import Console
from rich.table import Table


class ConsoleExporter:
    """
    A class to export the statistics and arg values to the console.
    """

    STAT_COLUMN_KEYS = ["avg", "min", "max", "p99", "p90", "p75"]

    def __init__(self, config: ExporterConfig):
        self._stats = config.stats
        self._telemetry_stats = config.telemetry_stats
        self._metrics = config.metrics
        self._args = config.args

    def _get_title(self):
        title = "NVIDIA GenAI-Perf | "
        if self._args.endpoint_type == "embeddings":
            title += "Embeddings Metrics"
        elif self._args.endpoint_type == "rankings":
            title += "Rankings Metrics"
        elif self._args.endpoint_type == "image_retrieval":
            title += "Image Retrieval Metrics"
        elif self._args.endpoint_type == "vision":
            title += "VLM Metrics"
        else:
            title += "LLM Metrics"
        return title

    def export(self) -> None:
        table = Table(title=self._get_title())

        table.add_column("Statistic", justify="right", style="cyan", no_wrap=True)
        for stat in self.STAT_COLUMN_KEYS:
            table.add_column(stat, justify="right", style="green")

        # Request metrics table
        self._construct_table(table)

        console = Console()
        console.print(table)
        if self._args.verbose:
            telem_utils.export_telemetry_stats_console(
                self._telemetry_stats, self.STAT_COLUMN_KEYS, console
            )

    def _construct_table(self, table: Table) -> None:
        for metric in self._metrics.request_metrics:
            if self._should_skip(metric.name):
                continue

            metric_str = metric.name.replace("_", " ").capitalize()
            metric_str += f" ({metric.unit})" if metric.unit != "tokens" else ""
            row_values = [metric_str]
            for stat in self.STAT_COLUMN_KEYS:
                value = self._stats[metric.name][stat]
                row_values.append(f"{value:,.2f}")

            table.add_row(*row_values)

        for metric in self._metrics.system_metrics:
            metric_str = metric.name.replace("_", " ").capitalize()
            # metric_str = metric_str.replace("throughput", "tput")
            if metric.name == "request_goodput":
                if not self._args.goodput:
                    continue
            metric_str += f" ({metric.unit})" if metric.unit != "tokens" else ""
            row_values = [metric_str]
            for stat in self.STAT_COLUMN_KEYS:
                if stat == "avg":
                    value = self._stats[metric.name]["avg"]
                    row_values.append(f"{value:,.2f}")
                else:
                    row_values.append("N/A")
            table.add_row(*row_values)

    # (TMA-1976) Refactor this method as the csv exporter shares identical method.
    def _should_skip(self, metric_name: str) -> bool:
        if self._args.endpoint_type == "embeddings":
            return False  # skip nothing

        # TODO (TMA-1712): need to decide if we need this metric. Remove
        # from statistics display for now.
        # TODO (TMA-1678): output_token_throughput_per_request is treated
        # separately since the current code treats all throughput metrics to
        # be displayed outside of the statistics table.
        if metric_name == "output_token_throughput_per_request":
            return True

        # When non-streaming, skip ITL and TTFT
        streaming_metrics = [
            "inter_token_latency",
            "time_to_first_token",
        ]
        if not self._args.streaming and metric_name in streaming_metrics:
            return True
        return False

==> genai_perf-0.0.12-py3-none-any.whl: genai_perf/export_data/console_exporter.py <==
# Copyright 2024, NVIDIA CORPORATION & AFFILIATES. All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#  * Neither the name of NVIDIA CORPORATION nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS ``AS IS'' AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
# OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


import genai_perf.logging as logging
from rich.console import Console
from rich.table import Table

from . import exporter_utils
from . import telemetry_data_exporter_util as telem_utils
from .exporter_config import ExporterConfig

logger = logging.getLogger(__name__)


class ConsoleExporter:
    """
    A class to export the statistics and arg values to the console.
    """

    STAT_COLUMN_KEYS = ["avg", "min", "max", "p99", "p90", "p75"]

    def __init__(self, config: ExporterConfig):
        self._stats = config.stats
        self._telemetry_stats = config.telemetry_stats
        self._metrics = config.metrics
        self._args = config.args

    def _get_title(self):
        title = "NVIDIA GenAI-Perf | "
        if self._args.endpoint_type == "embeddings":
            title += "Embeddings Metrics"
        elif self._args.endpoint_type == "rankings":
            title += "Rankings Metrics"
        elif self._args.endpoint_type == "image_retrieval":
            title += "Image Retrieval Metrics"
        elif self._args.endpoint_type == "vision":
            title += "VLM Metrics"
        else:
            title += "LLM Metrics"
        return title

    def export(self) -> None:
        table = Table(title=self._get_title())

        table.add_column("Statistic", justify="right", style="cyan", no_wrap=True)
        for stat in self.STAT_COLUMN_KEYS:
            table.add_column(stat, justify="right", style="green")

        # Request metrics table
        self._construct_table(table)

        console = Console()
        console.print(table)
        if self._args.verbose:
            telem_utils.export_telemetry_stats_console(
                self._telemetry_stats, self.STAT_COLUMN_KEYS, console
            )

    def _construct_table(self, table: Table) -> None:

        for metric in self._metrics.request_metrics:
            if self._should_skip(metric.name):
                continue

            metric_str = exporter_utils.format_metric_name(metric.name, metric.unit)
            row_values = [metric_str]

            for stat in self.STAT_COLUMN_KEYS:
                row_values.append(
                    exporter_utils.fetch_stat(self._stats, metric.name, stat)
                )

            table.add_row(*row_values)

        for metric in self._metrics.system_metrics:
            metric_str = exporter_utils.format_metric_name(metric.name, metric.unit)
            if metric.name == "request_goodput" and not self._args.goodput:
                continue

            row_values = [metric_str]
            for stat in self.STAT_COLUMN_KEYS:
                if stat == "avg":
                    row_values.append(
                        exporter_utils.fetch_stat(self._stats, metric.name, "avg")
                    )
                else:
                    row_values.append("N/A")

            table.add_row(*row_values)

    # (TMA-1976) Refactor this method as the csv exporter shares identical method.
    def _should_skip(self, metric_name: str) -> bool:
        if self._args.endpoint_type == "embeddings":
            return False  # skip nothing

        # TODO (TMA-1712): need to decide if we need this metric. Remove
        # from statistics display for now.
        # TODO (TMA-1678): output_token_throughput_per_request is treated
        # separately since the current code treats all throughput metrics to
        # be displayed outside of the statistics table.
        if metric_name == "output_token_throughput_per_request":
            return True

        # When non-streaming, skip ITL and TTFT
        streaming_metrics = [
            "inter_token_latency",
            "time_to_first_token",
            "time_to_second_token",
        ]
        if not self._args.streaming and metric_name in streaming_metrics:
            return True
        return False
